# -*- coding: utf-8 -*-
"""
-------------------------------------------------
   File Name:       ua
   Description:     User-Agent中间件
   Author:          MicLon
   date:            2021/8/30
-------------------------------------------------
"""
from .ua_list import ua_list


class UserAgentMiddleware:

    def __init__(self):
        ...

    def process_request(self, request, spider):
        random_ua = ua_list()
        if random_ua:
            request.headers.setdefault('User-Agent', random_ua)


#!/usr/bin/env python
# -*- coding:utf-8 -*-

from setuptools import setup, find_packages

setup(
    name="ml-scrapy",
    version="0.0.2",
    keywords=("pip", "scrapy"),
    description="Components For Scrapy Project",
    long_description="Components For Scrapy Project",
    license="MIT Licence",

    url="https://github.com/mic1on/ml-scrapy",
    author="miclon",
    author_email="jcnd@163.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
)
